rankeval\.scoring package
=========================

.. automodule:: rankeval.scoring
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

rankeval\.scoring\.scorer module
--------------------------------

.. automodule:: rankeval.scoring.scorer
    :members:
    :undoc-members:
    :show-inheritance:


